Author: https://www.facebook.com/mrillingram
Description: Awesome, fun, interesting videos and graphics about stuff that matters.

Close
Share on Facebook

## They're Innocent Looking Enough But Actually Quite Dangerous

Follow @MrillDill
Fact Checked

## FACTS!

…They’re a thing. We love them. We also know they’re hard to come by on the Internet. That’s why we have a team of fact-checkers double-checking everything we post, with standards that meet or exceed anyone else on the web. So go ahead and share your favorite thing from Upworthy with the full confidence that it's on the level — and that you’ll look really smart doing it. Not that you need any help with that, of course.

If we discover that something less-than-facty slipped through the cracks, we’ll always be up front with you. Check our corrections page for more information.

There's a surprising story to this piece of fruit, and weirdly, it starts with pineapples.

Share On Facebook
Share On TwitterTweet

### Holy moly!

As the video says, strawberries are safe to eat, and they're good for you too. But that doesn't mean the way we grow them is safe. The concerns here are the workers in the field and families who live near strawberry fields. A study by the California Department of Public Health found that almost 900 schools are within a 1.4-mile radius of regular use of known carcinogenic pesticides that you learned about in the video.

Also, strawberries and other fruits and vegetables aren't always chemical-free. Check out this comparison of pesticide residues found on fruits and vegetables. There's endless debate about the health impacts of consuming conventional vs. organic produce. The most important thing is to keep eating your fruits and veggies! But the chart below helps you figure out what non-organic produce is most likely to carry additional chemicals. (Psst, the most recent research moves strawberries up to #2!)

For more info, read the full Center for Investigative Reporting investigation on strawberry production, and if you live in California, check out this app to see if you live near areas where pesticides are heavily used to grow strawberries and other crops.

Share on Facebook
Share on Twitter
Share on Facebook

#### Next bit of Upworthiness:

## Want more stuff like this?

We're on a mission to spread meaningful content far and wide. Try our daily email, The Upworthiest, and see for yourself!

By submitting above you agree to the Upworthy privacy policy.

One-Click Subscribe

No time to type on that tiny screen? No problem! Click subscribe above, then hit send when the email pops up. Boom, you're done.

## Thanks for signing up!

Nice! Like us on Facebook to add daily goodness to your feed:

Nice! Subscribe to our YouTube channel to stay tuned to the most meaningful videos on the web.

## Want More Good Stuff?

Subscribe to our YouTube channel to stay tuned to the most meaningful videos on the web.

- ###

### Flash Video Embed

This video is not supported by your device. Continue browsing to find other stuff you'll love!

Close
Pinch or double-tap to zoom

Hey, Internet Friend. Looks like you're using a crazy old web browser, which is no longer supported. Please consider upgrading to something more modern—for a better experience, and a safer time online. We only want the best for you.

Download Google Chrome, and try it for a week. Don't think about it, just do it. You'll thank us later.